package com.aucma.base.service;

import java.util.List;
import com.aucma.base.domain.BaseFactory;

/**
 * 工厂管理Service接口
 * 
 * @author Yinq
 * @date 2023-09-18
 */
public interface IBaseFactoryService 
{
    /**
     * 查询工厂管理
     * 
     * @param objId 工厂管理主键
     * @return 工厂管理
     */
    public BaseFactory selectBaseFactoryByObjId(Long objId);

    /**
     * 查询工厂管理列表
     * 
     * @param baseFactory 工厂管理
     * @return 工厂管理集合
     */
    public List<BaseFactory> selectBaseFactoryList(BaseFactory baseFactory);

    /**
     * 新增工厂管理
     * 
     * @param baseFactory 工厂管理
     * @return 结果
     */
    public int insertBaseFactory(BaseFactory baseFactory);

    /**
     * 修改工厂管理
     * 
     * @param baseFactory 工厂管理
     * @return 结果
     */
    public int updateBaseFactory(BaseFactory baseFactory);

    /**
     * 批量删除工厂管理
     * 
     * @param objIds 需要删除的工厂管理主键集合
     * @return 结果
     */
    public int deleteBaseFactoryByObjIds(Long[] objIds);

    /**
     * 删除工厂管理信息
     * 
     * @param objId 工厂管理主键
     * @return 结果
     */
    public int deleteBaseFactoryByObjId(Long objId);
}
